@@ -25,6 +25,7 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
                  c1=2,
                  c2=2,
                  w=0.9):
+
         """       
         Parameters
         ----------
@@ -58,13 +59,13 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
         self.c2 = c2
         self.w = w
 
-    def _evaluate_fitness(self, model, X_train, y_train, X_valid, y_valid):
+    def _evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid):
         scores = []
         for i, individual in enumerate(self.individuals):
             chosen_features = [index for index in range(
-                X_train.shape[1]) if individual[index] == 1]
-            X_train_copy = X_train.iloc[:, chosen_features]
-            X_valid_copy = X_valid.iloc[:, chosen_features]
+                x_train.shape[1]) if individual[index] == 1]
+            X_train_copy = x_train.iloc[:, chosen_features]
+            X_valid_copy = x_valid.iloc[:, chosen_features]
             feature_hash = '_*_'.join(
                 sorted(self.feature_list[chosen_features]))
             if feature_hash in self.feature_score_hash.keys():
@@ -72,9 +73,10 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
             else:
                 score = self.objective_function(
                     model, X_train_copy, y_train, X_valid_copy, y_valid)
+                if not(self.minimize):
+                    score = -score
                 self.feature_score_hash[feature_hash] = score
-            if not(self.minimize):
-                score = -score
+            
             if score < self.current_best_scores[i]:
                 self.current_best_scores[i] = score
                 self.current_best_individual_score_dimensions[i] = individual
@@ -140,8 +142,6 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
 
             self.fitness_scores = self._evaluate_fitness(
                 model, X_train, y_train, X_valid, y_valid)
-            # if not(self.minimize):
-            #    self.fitness_scores=list(-np.array(self.fitness_scores))
 
             self.gbest_individual = self.best_dim
 
